@@ -26,7 +26,6 @@
 #include <qcommandlineparser.h>
 #include <qcommandlineoption.h>
 #include <QQuickItem>
-#include <QtQml>
 
 #include <kpackage/package.h>
 #include <kpackage/packageloader.h>
@@ -40,16 +39,14 @@
 
 int main(int argc, char **argv)
 {
-    QCommandLineParser parser;
     QApplication app(argc, argv);
 
-    const QString description = i18n("Plasma Theme Explorer");
-    const char version[] = PROJECT_VERSION;
+    app.setApplicationVersion(PROJECT_VERSION);
 
-    app.setApplicationVersion(version);
+    QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
-    parser.setApplicationDescription(description);
+    parser.setApplicationDescription(i18n("Plasma Theme Explorer"));
 
     QCommandLineOption themeOption(QCommandLineOption(QStringList() << "t" << "theme", i18n("The theme to open"), "theme"));
 
